DROP TABLE stuetzstellen;
DROP TABLE ganglinien;
DROP TABLE ereignisse;
DROP TABLE ereignistypen;


-- Tabelle mit den Ereignistypen 
CREATE TABLE ereignistypen (
	ereignistyp VARCHAR(50) NOT NULL,
	prioritaet INTEGER NOT NULL,
	ausschluss VARCHAR(50),
	bezug VARCHAR(50),
	typ INTEGER DEFAULT 0 NOT NULL,	
	vergleichsschrittweite BIGINT DEFAULT 60000 NOT NULL,
	max_abstand INTEGER DEFAULT 100 NOT NULL,
	max_matchingfehler INTEGER DEFAULT 15 NOT NULL,
	matchingschrittweite BIGINT DEFAULT 60000 NOT NULL,	
	matchingintervall_vor BIGINT DEFAULT 21600000 NOT NULL,
	matchingintervall_nach BIGINT DEFAULT 21600000 NOT NULL,
	max_wichtungsfaktor INTEGER DEFAULT 3 NOT NULL,
	darstellungsverfahren INTEGER DEFAULT 1 NOT NULL,
	max_ganglinien INTEGER DEFAULT 10 NOT NULL,

	PRIMARY KEY (ereignistyp),
	FOREIGN KEY (ereignistyp) REFERENCES ereignistypen(ereignistyp),
	FOREIGN KEY (ausschluss) REFERENCES ereignistypen(ereignistyp)
);
INSERT INTO ereignistypen (ereignistyp, prioritaet) VALUES ('TestMontag', 1020);
INSERT INTO ereignistypen (ereignistyp, prioritaet) VALUES ('TestMontagsfeiertag', 1080);
INSERT INTO ereignistypen (ereignistyp, prioritaet) VALUES ('TestFeiertag', 1060);
INSERT INTO ereignistypen (ereignistyp, prioritaet) VALUES ('TestOstermontag', 1100);


-- Tabelle mit den Ereignissen
-- "tag" ist der Tag an dem das Ereignis gltig sein soll, relativ zum heutigen
-- Tag: -1 = gestern, 0 = heute, 1 = morgen usw.
CREATE TABLE ereignisse (
	ereignistyp VARCHAR(50) NOT NULL,
	tag INTEGER NOT NULL,
	startzeit INTEGER DEFAULT 0 NOT NULL,
	endzeit INTEGER DEFAULT 24 NOT NULL,

	FOREIGN KEY (ereignistyp) REFERENCES ereignistypen(ereignistyp)
);
INSERT INTO ereignisse (ereignistyp, tag) VALUES ('TestMontag', 0);
INSERT INTO ereignisse (ereignistyp, tag) VALUES ('TestOstermontag', 0);
INSERT INTO ereignisse (ereignistyp, tag) VALUES ('TestMontagsfeiertag', 0);
INSERT INTO ereignisse (ereignistyp, tag) VALUES ('TestFeiertag', 0);


-- Tabelle mit den Ganglinie
CREATE TABLE ganglinien (
	id INTEGER NOT NULL,
	ereignistyp VARCHAR(50) NOT NULL,
	typ INTEGER DEFAULT 0 NOT NULL,
	approximation INTEGER DEFAULT 1 NOT NULL,
	referenz BOOLEAN DEFAULT false NOT NULL,

	PRIMARY KEY (id),
	FOREIGN KEY (ereignistyp) REFERENCES ereignistypen(ereignistyp)
);
INSERT INTO ganglinien (id, ereignistyp, referenz) VALUES (0, 'TestMontagsfeiertag', false);
INSERT INTO ganglinien (id, ereignistyp, referenz) VALUES (1, 'TestMontagsfeiertag', true);
INSERT INTO ganglinien (id, ereignistyp, referenz) VALUES (2, 'TestMontagsfeiertag', false);
INSERT INTO ganglinien (id, ereignistyp, referenz) VALUES (3, 'TestMontag', true);
INSERT INTO ganglinien (id, ereignistyp, referenz) VALUES (4, 'TestMontag', false);
INSERT INTO ganglinien (id, ereignistyp, referenz) VALUES (5, 'TestMontag', false);


-- Tabelle mit den Sttzstellen der Ganglinien
-- "tag" ist der Tag an dem das Ereignis gltig sein soll, relativ zum heutigen
-- Tag: -1 = gestern, 0 = heute, 1 = morgen usw.
-- undefinierte Stzstellenwerte sind NULL
CREATE TABLE stuetzstellen (
	gl_id INTEGER NOT NULL,
	tag INTEGER NOT NULL,
	stunde TIME NOT NULL,
	qkfz REAL,
	qlkw REAL,
	vpkw REAL,
	vlkw REAL,
	
	PRIMARY KEY (gl_id, tag, stunde),
	FOREIGN KEY (gl_id) REFERENCES ganglinien(id)
);


-- Testdaten fr Ganglinien importieren
CREATE TEXT TABLE csvimport_ganglinien (
	ganglinie INTEGER NOT NULL,
	tag INTEGER NOT NULL,
	stunde TIME NOT NULL,
	qkfz REAL,
	qlkw REAL,
	vpkw REAL,
	vlkw REAL
);
SET TABLE csvimport_ganglinien SOURCE "prueffall3_ganglinien.csv;ignore_first=true;fs=\semi";
INSERT INTO stuetzstellen (gl_id, tag, stunde, qkfz, qlkw, vpkw, vlkw)
	SELECT ganglinie, tag, stunde, qkfz, qlkw, vpkw, vlkw FROM csvimport_ganglinien;
SET TABLE csvimport_ganglinien SOURCE OFF;
DROP TABLE csvimport_ganglinien;
