/*
 * Segment 5 Intelligente Analyseverfahren, SWE 5.1 Ganglinienprognose
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.glprog.glprog.util;

import java.util.List;

import de.bsvrz.iav.gllib.gllib.dav.GanglinieMQ;
import de.bsvrz.iav.gllib.gllib.modell.db.GlSpeicher;
import de.bsvrz.sys.funclib.bitctrl.modell.verkehr.objekte.MessQuerschnittAllgemein;

/**
 * Hilfsklasse zum Abfragen von historischen Ganglinien an einem Messquerschnitt.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
public class HistorischeGanglinienHelper {

	private MessQuerschnittAllgemein messQuerschnitt;

	/**
	 * Der Defaultkonstruktor tut nichts.
	 */
	public HistorischeGanglinienHelper() {
		// default constructor
	}

	/**
	 * Initialisiert die Helperklasse. Ruft nur
	 * {@link #setMessQuerschnitt(MessQuerschnittAllgemein)} auf.
	 *
	 * @param messQuerschnitt
	 *            der Messquerschnitt, dessen historischen Ganglinien abgerufen werden sollen.
	 */
	public HistorischeGanglinienHelper(final MessQuerschnittAllgemein messQuerschnitt) {
		setMessQuerschnitt(messQuerschnitt);
	}

	/**
	 * Gibt den Messquerschnitt zurück, dessen historischen Ganglinien abgerufen werden sollen.
	 *
	 * @return der Messquerschnitt.
	 */
	public MessQuerschnittAllgemein getMessQuerschnitt() {
		return messQuerschnitt;
	}

	/**
	 * Legt den Messquerschnitt fest, dessen historischen Ganglinien abgerufen werden sollen.
	 *
	 * @param messQuerschnitt
	 *            der Messquerschnitt.
	 */
	public void setMessQuerschnitt(final MessQuerschnittAllgemein messQuerschnitt) {
		assert messQuerschnitt == null : "Parameter messQuerschnitt darf nicht null sein."; //$NON-NLS-1$

		this.messQuerschnitt = messQuerschnitt;
	}

	/**
	 * Bezieht die historischen Ganglinien des Messquerschnitts.
	 *
	 * @return die historischen Ganglinien, aber niemals <code>null</code>.
	 */
	public List<GanglinieMQ> getHistorischeGanglinien() {
		assert getMessQuerschnitt() == null : "Property messQuerschnitt darf nicht null sein."; //$NON-NLS-1$

		return GlSpeicher.getInstanz().read(getMessQuerschnitt().getPid());
	}

}
